==> haskell-non-negative-0.1.2-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: non-negative
version: 0.1.2
id: non-negative-0.1.2-AZoiEBEtYZ6EOf9p0UR8go
key: non-negative-0.1.2-AZoiEBEtYZ6EOf9p0UR8go
license: LicenseRef-GPL
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
author: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://code.haskell.org/~thielema/non-negative/
synopsis: Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.
category: Math
abi: 3823289d8e6bfbbe4d6dce1ad06ebe8d
exposed: True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper
hidden-modules: Numeric.NonNegative.ChunkyPrivate
import-dirs: /usr/lib/ghc-8.6.5/site-local/non-negative-0.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/non-negative-0.1.2
hs-libraries: HSnon-negative-0.1.2-AZoiEBEtYZ6EOf9p0UR8go
depends:
    QuickCheck-2.13.1-7krqagqcRmA9RWDtUhyOg8 base-4.12.0.0
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-non-negative/html/non-negative.haddock
haddock-html: /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-non-negative-0.1.2-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: non-negative
version: 0.1.2
id: non-negative-0.1.2-Jp1inQ5KnlsJlTjedR7ysi
key: non-negative-0.1.2-Jp1inQ5KnlsJlTjedR7ysi
license: LicenseRef-GPL
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
author: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://code.haskell.org/~thielema/non-negative/
synopsis: Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.
category: Math
abi: 52d7aea6b56630f7a5303da6646fdd75
exposed: True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper
hidden-modules: Numeric.NonNegative.ChunkyPrivate
import-dirs: /usr/lib/ghc-8.6.5/site-local/non-negative-0.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/non-negative-0.1.2
hs-libraries: HSnon-negative-0.1.2-Jp1inQ5KnlsJlTjedR7ysi
depends:
    QuickCheck-2.13.2-52gUk4jYsn5ItHsbXhjyg4 base-4.12.0.0
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-non-negative/html/non-negative.haddock
haddock-html: /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
